package org.spring4d;

import org.sonar.api.SonarRuntime;
import org.sonar.api.server.rule.RulesDefinition;
import org.sonar.plugins.communitydelphi.api.check.MetadataResourcePath;
import org.sonar.plugins.communitydelphi.api.check.RuleTemplateAnnotationReader;
import org.sonarsource.analyzer.commons.RuleMetadataLoader;

public class SpringDelphiRulesDefinition implements RulesDefinition {
  private final SonarRuntime runtime;
  private final MetadataResourcePath metadataResourcePath;

  public SpringDelphiRulesDefinition(
      SonarRuntime runtime, MetadataResourcePath metadataResourcePath) {
    this.runtime = runtime;
    this.metadataResourcePath = metadataResourcePath;
  }

  @Override
  public void define(Context context) {
    NewRepository repository =
        context.createRepository(RulesList.REPOSITORY_KEY, "delphi").setName("Spring Delphi");

    String resourceFolder = metadataResourcePath.forRepository(repository.key());

    RuleMetadataLoader ruleMetadataLoader = new RuleMetadataLoader(resourceFolder, runtime);
    RuleTemplateAnnotationReader ruleTemplateAnnotationReader = new RuleTemplateAnnotationReader();

    ruleMetadataLoader.addRulesByAnnotatedClass(repository, RulesList.getChecks());
    ruleTemplateAnnotationReader.updateRulesByAnnotatedClass(repository, RulesList.getChecks());

    repository.done();
  }
}
